*****
Usage
*****

.. Setting analytic budgets:

Setting analytic budgets
========================

New `Analytic Budgets <model-analytic_account.budget>` can easily be created,
and existing budgets updated, by changing the budgets that are found in the
[:menuselection:`Financial --> Budgets --> Analytic Budgets`] main menu entry.

.. tip::

   To quickly add missing lines to a budget, you can use the :guilabel:`Update
   Lines` button. This creates a budget line for each missing analytic account.

.. tip::

   An analytic budget can be copied by using the `Copy Budget
   <wizard-analytic_account.budget.copy>` wizard from the budget's
   :guilabel:`Copy` button.

.. Tracking analytic budgets

Tracking analytic budgets
=========================

A report of actual amounts of each `Analytic Budget
<model-analytic_account.budget>` can be found by opening the
[:menuselection:`Financial --> Reporting --> Analytic Budgets`] main menu item.
